SimpleAudioFocusManager class

Constructors

SimpleAudioFocusManager()
factory

Properties

audioFocusStream ↔ Stream<SimpleAudioFocusState>
getter/setter pair
becomingNoisyStream ↔ Stream
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

giveUpAudioFocus() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
tryToGetAudioFocus() → Future<bool>

Operators

operator ==(Object other) → bool
The equality operator.
inherited